summaryrefslogtreecommitdiff
path: root/svx/source/engine3d/scene3d.cxx
diff options
context:
space:
mode:
authorArmin Le Grand <Armin.Le.Grand@Sun.COM>2010-05-10 13:48:23 +0200
committerArmin Le Grand <Armin.Le.Grand@Sun.COM>2010-05-10 13:48:23 +0200
commit953f5e62d7105cf4de1e46c6b3be048d2d60490d (patch)
tree1223606938b8dcc7aaaaf1514ec500d85b82cc1d /svx/source/engine3d/scene3d.cxx
parent88572c217b53b10a7d3ce1a0544813bf6fdc8bc0 (diff)
#i111410# reset BoundRects of 3D scenes udes as groups for chart
Diffstat (limited to 'svx/source/engine3d/scene3d.cxx')
-rw-r--r--svx/source/engine3d/scene3d.cxx14
1 files changed, 12 insertions, 2 deletions
diff --git a/svx/source/engine3d/scene3d.cxx b/svx/source/engine3d/scene3d.cxx
index d799aec38eb7..036f700e6e96 100644
--- a/svx/source/engine3d/scene3d.cxx
+++ b/svx/source/engine3d/scene3d.cxx
@@ -336,8 +336,18 @@ UINT16 E3dScene::GetObjIdentifier() const
void E3dScene::SetBoundRectDirty()
{
- // avoid resetting aOutRect which in case of this object is model data,
- // not re-creatable view data
+ E3dScene* pScene = GetScene();
+
+ if(pScene == this)
+ {
+ // avoid resetting aOutRect which in case of a 3D scene used as 2d object
+ // is model data,not re-creatable view data
+ }
+ else
+ {
+ // if not the outmost scene it is used as group in 3d, call parent
+ E3dObject::SetBoundRectDirty();
+ }
}
/*************************************************************************